@@ -28,7 +28,7 @@ import ctypes
 import time
 import multiprocessing
 import _thread
-
+import jieba
 print('import chlt.Chinese_learn')
 from chrc.Chinese_learn import *
 print(text_display_button)
@@ -340,8 +340,15 @@ class language_learner:
 
     def creat_buttons(self):
         n = len(self.input_text)
+        input_text=re.findall(r'[\u4e00-\u9fa5]', self.input_text)
+        seg_list = jieba.cut(''.join(self.input_text), cut_all=False)
+        seg = ", ".join(seg_list)
+        self.seg_list = seg.split(", ")
+        print(self.seg_list)
+        n = len(self.seg_list)
         # print(input_text)
 
+
         cols = 15
         rows =ceil(n/cols)
 
@@ -356,14 +363,19 @@ class language_learner:
         # print(x)
         button_size = 28
         for j in range(rows+1):
+            width = 0
             for i in range(cols):
                 if n>0:
                     t = text_display_button(root = self.top,
-                    input_text=self.input_text[i+j*cols],
+                    input_text=self.seg_list[i+j*cols],
                     button_size = button_size,
                     path_name=self.path_source)
                     # t.grid(row=j+1, column=i)
-                    t.place(relx=0.05+i*0.06, rely=0.25+j*0.12)
+                    print(self.seg_list[i+j*cols])
+
+                    t.place(relx=0.05+width*0.043, rely=0.25+j*0.12)
+                    width += len(self.seg_list[i+j*cols])
+                    # t.place(relx=0.05+i*0.06, rely=0.25+j*0.12)
                     self.button_object_list.append(t)
                     n = n-1
 
@@ -536,12 +548,12 @@ class language_learner:
         if self.button_start['text'] == 'Start' or self.button_start['text'] == 'Next':
             # self.button_start.config(state = 'disabled')
             self.countdown()
-            print('next problem index:',self.problem_index)
+            # # print('next problem index:',self.problem_index)
             # i = self.problem_index
             if self.problem_index == 0:
                 self.initialize_widgets_for_start()
                 self.generate_problem_list_from_database()
-                # print(self.report_dict)
+                # # print(self.report_dict)
 
             if self.problem_index < self.rounds_config:
                 r = int(self.rounds_val.get())-1
@@ -586,7 +598,7 @@ class language_learner:
     def button_read_callback(self):
         if self.button_read['text'] == 'Read':
             # txt = self.label_word['text']
-            # print(self.input_text)
+            # # print(self.input_text)
             txt = self.input_text
             self.read(self.input_text)
             if self.problem_index <= self.rounds_config and self.problem_index>0:
@@ -620,9 +632,9 @@ class language_learner:
                     self.report_dict['correct'][self.problem_index-1] = 0
                     problem = self.report_dict['problem'][self.problem_index-1]
                     problem = remove_str_punctuation(problem)
-                    print(problem)
+                    # print(problem)
                     l = self.check_language_type(problem)
-                    print(l)
+                    # print(l)
                     while not os.path.isfile(self.cur_audio_record_file_path):
                         time.sleep(0.2)
 
@@ -674,7 +686,7 @@ class language_learner:
             self.button_start['text'] = 'Next'
             self.countdown()
             # self.problem_index
-            print('problem index:',self.problem_index)
+            # print('problem index:',self.problem_index)
             # i = self.problem_index
             if self.problem_index == 0:
                 self.initialize_widgets_for_start()
@@ -715,7 +727,7 @@ class language_learner:
 
                 self.path_csv = os.path.dirname(self.report_filename)
                 self.path_csv = self.path_csv[:-9]
-                print(self.path_csv)
+                # print(self.path_csv)
                 self.report_path = self.generate_new_folder('L_report')
                 self.record_path = self.generate_new_folder('L_record')
                 self.source_path = self.generate_new_folder('L_source')
@@ -994,7 +1006,7 @@ class language_learner:
             else:
                 pass
             self.problem_index_list = [x for x in range(self.rounds_config)]
-        print(self.problem_index_list)
+        # print(self.problem_index_list)
         for i in self.problem_index_list:
             txt = str(self.df_f[i])
             txt_list.append(txt)
